#include <stdlib.h>
#include <avr/io.h>
#include <util/delay.h>
#include "i2c.h"
#include "lcd.h"
#include "MCP79410.h"

uint8_t testSRAM();
uint8_t testEEPROM();

int main(void)
{
    lcdInit();
	lcdInitPrintf();
	i2cInit();
	if (testSRAM()) printf("SRAM OK"); else printf("RAM ERROR");
	lcdGotoXY(0, 1);
	if (testEEPROM()) printf("EEPROM OK"); else printf("EEPROM ERROR");
    while (1) 
    {
    }
}

uint8_t testSRAM() {
	uint8_t input[64];
	uint8_t output[64];
	for (uint8_t i = 0; i < sizeof(input); i++) {
		input[i] = rand();
	}
	rtcWriteRegisters(0x20, input, sizeof(input));
	rtcReadRegisters(0x20, output, sizeof(input));
	for (uint8_t i = 0; i < sizeof(input); i++) {
		if (output[i] != input[i]) {
			return 0;
		}
	}
	return 1;
}

uint8_t testEEPROM() {
	for (uint8_t page = 0; page < 16; page++) {
		uint8_t input[8];
		uint8_t output[8];
		for (uint8_t i = 0; i < sizeof(input); i++) {
			input[i] = rand();
		}
		eepromWriteBytes(page * 8, input, sizeof(input));
		while (eepromIsBusy()) _delay_ms(1);
		eepromReadBytes(page * 8, output, sizeof(input));
		for (uint8_t i = 0; i < sizeof(input); i++) {
			if (output[i] != input[i]) {
				return 0;
			}
		}
	}
	return 1;
}

